pub struct FloatFormat;Expand description
Formats a float.
Arguments
- The number to format.
- The amount of desired digits after the decimal point. If set to 0, the formatter will automatically choose a length. 3? The amount of desired digits before the decimal point. Defaults to 1. 4? Whether to use scientific notation. Defaults to false.