pub struct Ease;Expand description
Interpolates a value using a given time and easing method.
Supported easings:
back, bounce, circ, elastic, expo, sine, quad, cubic, quart, quint, linear
All easings except for linear must be followed by _in, _out, or _in_out.
For more information, see https://easings.net/.
Arguments
- The number at the start of the easing animation.
- The number at the end of the easing animation.
- The time the easing animation should calculate.
- The easing animation kind.