pub struct ExprDef;Expand description
Parses a RPN expression and saves it to a function variable.
Syntax
Expressions are defined using Reverse Polish Notation.
For example, 1 2 + -> 3.
Each operator or number (generally called a node) must be
separated by at least one whitespace character.
Also supported is the node $N, for input values, and
#<ident>, which allows calling other expressions inside of an expression.
Calling an expression will pop its required arguments from the stack.
For example, [expr.def/inc/1 +][expr.call/inc/5] -> 6.
Supported Operators
**: Exponentlog: Log of arg 1 with base of arg 2abs: Absolute value<=>: Three-way comparison!=: Not equal==: Equal<=: Less or equal>=: Greater or equal<<: Left shift>>: Logical right shift>>>: Arithmetic right shift<: Less>: Greater+: Add-: Subtract*: Multiply/: Divide%: Modulus~: Negate?: Ternary (if first argument is nonzero, choose first argument, otherwise choose second argument)&: Bitwise AND|: Bitwise OR^: Bitwise XOR!: Bitwise NOTsin: Sinecos: Cosinetan: Tangentasin: Arcsineacos: Arccosineatan: Arctangentreal: Real component of complex numberimag: Imaginary component of complex numberarg: Argument of complex number
Arguments
- The name to save the expression under. 2… The expression